Reorder — Poezio 0.9-dev documentation

# Reorder

`reorder` plugin: Reorder the tabs according to a layout

## Commands

/reorder

  Usage: `/reorder`

  Reorder the tabs according to the configuration.

## Configuration

The configuration file must contain a section `[reorder]` and each option must be formatted like `[tab number] = [tab type]:[tab name]`.

For example:

    [reorder]
    1 = muc:toto@conference.example.com
    2 = muc:example@muc.example.im
    3 = dynamic:robert@example.org

The `[tab number]` must be at least `1`; if the range is not entirely covered, e.g.:

    [reorder]
    1 = muc:toto@conference.example.com
    3 = dynamic:robert@example.org

Poezio will insert gaps between the tabs in order to keep the specified numbering (so in this case, there will be a tab 1, a tab 3, but no tab 2).

The `[tab type]` must be one of:

- `muc` (for multi-user chats)
- `private` (for chats with a specific user inside a multi-user chat)
- `dynamic` (for normal, dynamic conversations tabs)
- `static` (for conversations with a specific resource)

And finally, the `[tab name]` must be:

- For a type `muc`, the bare JID of the room
- For a type `private`, the full JID of the user (room JID with the username as a resource)
- For a type `dynamic`, the bare JID of the contact
- For a type `static`, the full JID of the contact